@@ -1050,6 +1050,8 @@ def _start(client, bot):
 									await msg.edit(embed=emb)
 								except:
 									pass
+						elif line.startswith("$varsFile"):
+							await ctx.send(file=discord.File(bot._db.path+"vars.json"))
 						elif line.startswith("$sendEmbed"+bot._style[0]):
 							if line[-1]==bot._style[1]:
 								line=line[len("$sendEmbed"+bot._style[0]):]
